<?php
/**
 * @file
 * Contains the responsive grid style plugin.
 */

/**
 * Style plugin to render each item in a responsive grid.
 *
 * @ingroup views_style_plugins
 */
class views_responsive_grid_plugin_style_responsive_grid extends views_plugin_style {
  /**
   * Set default options.
   */
  function option_definition() {
    $options = parent::option_definition();
    $options['wrapper_classes'] = array('default' => '');
    $options['columns'] = array('default' => '4');
    $options['alignment'] = array('default' => 'horizontal');
    $options['column_css']['column_classes'] = array('default' => 'views-column');
    $options['column_css']['first_column_classes'] = array('default' => 'views-column-first');
    $options['column_css']['last_column_classes'] = array('default' => 'views-column-last');
    $options['row_css']['row_classes'] = array('default' => 'views-row');
    $options['row_css']['first_row_classes'] = array('default' => 'views-row-first');
    $options['row_css']['last_row_classes'] = array('default' => 'views-row-last');
    $options['default_classes'] = array('default' => 0);
    return $options;
  }

  /**
   * Render the given style.
   */
  function options_form(&$form, &$form_state) {
    parent::options_form($form, $form_state);
    $form['wrapper_classes'] = array(
      '#type' => 'textfield',
      '#title' => t('Wrapper Class'),
      '#description' => t('Name of the class(es) to be used for the entire wrapper. Separated by spaces.'),
      '#default_value' => $options['wrapper_class'],
    );
    $form['columns'] = array(
      '#type' => 'textfield',
      '#title' => t('Number of columns'),
      '#default_value' => $this->options['columns'],
      '#required' => TRUE,
      '#element_validate' => array('views_element_validate_integer'),
    );
    $form['alignment'] = array(
      '#type' => 'radios',
      '#title' => t('Alignment'),
      '#options' => array('horizontal' => t('Horizontal'), 'vertical' => t('Vertical')),
      '#default_value' => $this->options['alignment'],
      '#description' => t('Horizontal alignment will place items starting in the upper left and moving right. Vertical alignment will place items starting in the upper left and moving down.'),
    );
    $form['column_css'] = array(
      '#type' => 'fieldset',
      '#title' => t('Columns'),
      '#weight' => 1,
    );
    $form['column_css']['column_classes'] = array(
      '#type' => 'textfield',
      '#title' => t('Column Classes'),
      '#description' => t('Name of the class(es) being used for every column. Separated by spaces.'),
      '#default_value' => $this->options['columns']['column_classes'],
    );
    $form['column_css']['first_column_classes'] = array(
      '#type' => 'textfield',
      '#title' => t('First Column Classes'),
      '#description' => t('Name of the class(es) being used for the first column. Separated by spaces.'),
      '#default_value' => $this->options['columns']['first_column_classes'],
    );
    $form['column_css']['last_column_classes'] = array(
      '#type' => 'textfield',
      '#title' => t('Last Column Classes'),
      '#description' => t('Name of the class(es) being used for the last column. Separated by spaces.'),
      '#default_value' => $this->options['columns']['last_column_classes'],
    );
    $form['row_css'] = array(
      '#type' => 'fieldset',
      '#title' => t('Row'),
      '#weight' => 2,
    );
    $form['row_css']['row_classes'] = array(
      '#type' => 'textfield',
      '#title' => t('Row Classes'),
      '#description' => t('Name of the class(es) being used for every row. Separated by spaces.'),
      '#default_value' => $this->options['rows']['row_classes'],
    );
    $form['row_css']['first_row_classes'] = array(
      '#type' => 'textfield',
      '#title' => t('First Row Classes'),
      '#description' => t('Name of the class(es) being used for the first row. Separated by spaces.'),
      '#default_value' => $this->options['rows']['first_row_classes'],
    );
    $form['row_css']['last_row_classes'] = array(
      '#type' => 'textfield',
      '#title' => t('Last Row Classes'),
      '#description' => t('Name of the class(es) being used for the last row. Separated by spaces.'),
      '#default_value' => $this->options['rows']['last_row_classes'],
    );
    $form['default_classes'] = array(
      '#type' => 'checkbox',
      '#title' => t('Remove default views classes'),
      '#default_value' => $this->options['default_classes'],
      '#return_value' => 1,
      '#weight' => 3,
    );
  }
}
